Exceptions
==========

pyvergeos defines a hierarchy of exceptions for error handling.

Exception Classes
-----------------

.. automodule:: pyvergeos.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

Filters
-------

.. automodule:: pyvergeos.filters
   :members:
   :undoc-members:
   :show-inheritance:
